@@ -5,8 +5,9 @@ function (
 	, sid
 	, within = NULL
 	, between = NULL
+	, between_full = NULL
 ){
-	from_ezStats_main = ezStats_main(data,dv,sid,within,between)
+	from_ezStats_main = ezStats_main(data,dv,sid,within,between,between_full)
 	return(from_ezStats_main$Descriptives)
 }
 
